==> jboss-as-maven-plugin-7.1.1.Final-sources.jar: org/jboss/as/plugin/deployment/Deployment.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.plugin.deployment;

import java.io.Closeable;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.MojoFailureException;

/**
 * @author <a href="mailto:jperkins@redhat.com">James R. Perkins</a>
 */
public interface Deployment extends Closeable {

    public enum Type {
        DEPLOY,
        FORCE_DEPLOY,
        UNDEPLOY,
        UNDEPLOY_IGNORE_MISSING,
        REDEPLOY,
    }

    public enum Status {
        SUCCESS,
        REQUIRES_RESTART
    }

    static final String CHILD_TYPE = "child-type";

    static final String FAILED = "failed";

    static final String READ_CHILDREN_NAMES_OPERATION = "read-children-names";

    /**
     * Executes the deployment
     *
     * @return the status of the execution.
     *
     * @throws MojoExecutionException if the deployment fails
     * @throws MojoFailureException   if a failure occurs.
     */
    Status execute() throws MojoExecutionException, MojoFailureException;

    /**
     * The type of the deployment.
     *
     * @return the type of the deployment.
     */
    Type getType();
}

==> jboss-as-maven-plugin-7.2.Final-sources.jar: org/jboss/as/plugin/deployment/Deployment.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.jboss.as.plugin.deployment;

import org.jboss.as.plugin.common.DeploymentExecutionException;
import org.jboss.as.plugin.common.DeploymentFailureException;

/**
 * @author <a href="mailto:jperkins@redhat.com">James R. Perkins</a>
 */
public interface Deployment {

    public enum Type {
        DEPLOY,
        FORCE_DEPLOY,
        UNDEPLOY,
        UNDEPLOY_IGNORE_MISSING,
        REDEPLOY,
    }

    public enum Status {
        SUCCESS,
        REQUIRES_RESTART
    }

    /**
     * Executes the deployment
     *
     * @return the status of the execution.
     *
     * @throws DeploymentExecutionException if the deployment fails
     * @throws DeploymentFailureException   if a failure occurs.
     */
    Status execute() throws DeploymentExecutionException, DeploymentFailureException;

    /**
     * The type of the deployment.
     *
     * @return the type of the deployment.
     */
    Type getType();
}
